@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import ApplyMethodType, SourceTypeType
 
@@ -182,7 +182,7 @@ AddTagsToResourceMessageRequestTypeDef = TypedDict(
     "AddTagsToResourceMessageRequestTypeDef",
     {
         "ResourceName": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -236,8 +236,8 @@ CertificateTypeDef = TypedDict(
 CloudwatchLogsExportConfigurationTypeDef = TypedDict(
     "CloudwatchLogsExportConfigurationTypeDef",
     {
-        "EnableLogTypes": List[str],
-        "DisableLogTypes": List[str],
+        "EnableLogTypes": Sequence[str],
+        "DisableLogTypes": Sequence[str],
     },
     total=False,
 )
@@ -253,7 +253,7 @@ _RequiredCopyDBClusterParameterGroupMessageRequestTypeDef = TypedDict(
 _OptionalCopyDBClusterParameterGroupMessageRequestTypeDef = TypedDict(
     "_OptionalCopyDBClusterParameterGroupMessageRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -287,7 +287,7 @@ _OptionalCopyDBClusterSnapshotMessageRequestTypeDef = TypedDict(
         "KmsKeyId": str,
         "PreSignedUrl": str,
         "CopyTags": bool,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "SourceRegion": str,
     },
     total=False,
@@ -319,10 +319,10 @@ _RequiredCreateDBClusterMessageRequestTypeDef = TypedDict(
 _OptionalCreateDBClusterMessageRequestTypeDef = TypedDict(
     "_OptionalCreateDBClusterMessageRequestTypeDef",
     {
-        "AvailabilityZones": List[str],
+        "AvailabilityZones": Sequence[str],
         "BackupRetentionPeriod": int,
         "DBClusterParameterGroupName": str,
-        "VpcSecurityGroupIds": List[str],
+        "VpcSecurityGroupIds": Sequence[str],
         "DBSubnetGroupName": str,
         "EngineVersion": str,
         "Port": int,
@@ -330,11 +330,11 @@ _OptionalCreateDBClusterMessageRequestTypeDef = TypedDict(
         "MasterUserPassword": str,
         "PreferredBackupWindow": str,
         "PreferredMaintenanceWindow": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "StorageEncrypted": bool,
         "KmsKeyId": str,
         "PreSignedUrl": str,
-        "EnableCloudwatchLogsExports": List[str],
+        "EnableCloudwatchLogsExports": Sequence[str],
         "DeletionProtection": bool,
         "GlobalClusterIdentifier": str,
         "SourceRegion": str,
@@ -360,7 +360,7 @@ _RequiredCreateDBClusterParameterGroupMessageRequestTypeDef = TypedDict(
 _OptionalCreateDBClusterParameterGroupMessageRequestTypeDef = TypedDict(
     "_OptionalCreateDBClusterParameterGroupMessageRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -399,7 +399,7 @@ _RequiredCreateDBClusterSnapshotMessageRequestTypeDef = TypedDict(
 _OptionalCreateDBClusterSnapshotMessageRequestTypeDef = TypedDict(
     "_OptionalCreateDBClusterSnapshotMessageRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -435,7 +435,7 @@ _OptionalCreateDBInstanceMessageRequestTypeDef = TypedDict(
         "AvailabilityZone": str,
         "PreferredMaintenanceWindow": str,
         "AutoMinorVersionUpgrade": bool,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "PromotionTier": int,
     },
     total=False,
@@ -461,13 +461,13 @@ _RequiredCreateDBSubnetGroupMessageRequestTypeDef = TypedDict(
     {
         "DBSubnetGroupName": str,
         "DBSubnetGroupDescription": str,
-        "SubnetIds": List[str],
+        "SubnetIds": Sequence[str],
     },
 )
 _OptionalCreateDBSubnetGroupMessageRequestTypeDef = TypedDict(
     "_OptionalCreateDBSubnetGroupMessageRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -499,10 +499,10 @@ _OptionalCreateEventSubscriptionMessageRequestTypeDef = TypedDict(
     "_OptionalCreateEventSubscriptionMessageRequestTypeDef",
     {
         "SourceType": str,
-        "EventCategories": List[str],
-        "SourceIds": List[str],
+        "EventCategories": Sequence[str],
+        "SourceIds": Sequence[str],
         "Enabled": bool,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -920,7 +920,7 @@ DescribeCertificatesMessageRequestTypeDef = TypedDict(
     "DescribeCertificatesMessageRequestTypeDef",
     {
         "CertificateIdentifier": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -931,7 +931,7 @@ DescribeDBClusterParameterGroupsMessageRequestTypeDef = TypedDict(
     "DescribeDBClusterParameterGroupsMessageRequestTypeDef",
     {
         "DBClusterParameterGroupName": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -948,7 +948,7 @@ _OptionalDescribeDBClusterParametersMessageRequestTypeDef = TypedDict(
     "_OptionalDescribeDBClusterParametersMessageRequestTypeDef",
     {
         "Source": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -984,7 +984,7 @@ DescribeDBClusterSnapshotsMessageRequestTypeDef = TypedDict(
         "DBClusterIdentifier": str,
         "DBClusterSnapshotIdentifier": str,
         "SnapshotType": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
         "IncludeShared": bool,
@@ -997,7 +997,7 @@ DescribeDBClustersMessageRequestTypeDef = TypedDict(
     "DescribeDBClustersMessageRequestTypeDef",
     {
         "DBClusterIdentifier": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -1010,7 +1010,7 @@ DescribeDBEngineVersionsMessageRequestTypeDef = TypedDict(
         "Engine": str,
         "EngineVersion": str,
         "DBParameterGroupFamily": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
         "DefaultOnly": bool,
@@ -1024,7 +1024,7 @@ DescribeDBInstancesMessageRequestTypeDef = TypedDict(
     "DescribeDBInstancesMessageRequestTypeDef",
     {
         "DBInstanceIdentifier": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -1035,7 +1035,7 @@ DescribeDBSubnetGroupsMessageRequestTypeDef = TypedDict(
     "DescribeDBSubnetGroupsMessageRequestTypeDef",
     {
         "DBSubnetGroupName": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -1051,7 +1051,7 @@ _RequiredDescribeEngineDefaultClusterParametersMessageRequestTypeDef = TypedDict
 _OptionalDescribeEngineDefaultClusterParametersMessageRequestTypeDef = TypedDict(
     "_OptionalDescribeEngineDefaultClusterParametersMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -1078,7 +1078,7 @@ DescribeEventCategoriesMessageRequestTypeDef = TypedDict(
     "DescribeEventCategoriesMessageRequestTypeDef",
     {
         "SourceType": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1087,7 +1087,7 @@ DescribeEventSubscriptionsMessageRequestTypeDef = TypedDict(
     "DescribeEventSubscriptionsMessageRequestTypeDef",
     {
         "SubscriptionName": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -1102,8 +1102,8 @@ DescribeEventsMessageRequestTypeDef = TypedDict(
         "StartTime": Union[datetime, str],
         "EndTime": Union[datetime, str],
         "Duration": int,
-        "EventCategories": List[str],
-        "Filters": List["FilterTypeDef"],
+        "EventCategories": Sequence[str],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -1114,7 +1114,7 @@ DescribeGlobalClustersMessageRequestTypeDef = TypedDict(
     "DescribeGlobalClustersMessageRequestTypeDef",
     {
         "GlobalClusterIdentifier": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -1134,7 +1134,7 @@ _OptionalDescribeOrderableDBInstanceOptionsMessageRequestTypeDef = TypedDict(
         "DBInstanceClass": str,
         "LicenseModel": str,
         "Vpc": bool,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -1153,7 +1153,7 @@ DescribePendingMaintenanceActionsMessageRequestTypeDef = TypedDict(
     "DescribePendingMaintenanceActionsMessageRequestTypeDef",
     {
         "ResourceIdentifier": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "Marker": str,
         "MaxRecords": int,
     },
@@ -1266,7 +1266,7 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
         "Name": str,
-        "Values": List[str],
+        "Values": Sequence[str],
     },
 )
 
@@ -1315,7 +1315,7 @@ _RequiredListTagsForResourceMessageRequestTypeDef = TypedDict(
 _OptionalListTagsForResourceMessageRequestTypeDef = TypedDict(
     "_OptionalListTagsForResourceMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1341,7 +1341,7 @@ _OptionalModifyDBClusterMessageRequestTypeDef = TypedDict(
         "ApplyImmediately": bool,
         "BackupRetentionPeriod": int,
         "DBClusterParameterGroupName": str,
-        "VpcSecurityGroupIds": List[str],
+        "VpcSecurityGroupIds": Sequence[str],
         "Port": int,
         "MasterUserPassword": str,
         "PreferredBackupWindow": str,
@@ -1364,7 +1364,7 @@ ModifyDBClusterParameterGroupMessageRequestTypeDef = TypedDict(
     "ModifyDBClusterParameterGroupMessageRequestTypeDef",
     {
         "DBClusterParameterGroupName": str,
-        "Parameters": List["ParameterTypeDef"],
+        "Parameters": Sequence["ParameterTypeDef"],
     },
 )
 
@@ -1386,8 +1386,8 @@ _RequiredModifyDBClusterSnapshotAttributeMessageRequestTypeDef = TypedDict(
 _OptionalModifyDBClusterSnapshotAttributeMessageRequestTypeDef = TypedDict(
     "_OptionalModifyDBClusterSnapshotAttributeMessageRequestTypeDef",
     {
-        "ValuesToAdd": List[str],
-        "ValuesToRemove": List[str],
+        "ValuesToAdd": Sequence[str],
+        "ValuesToRemove": Sequence[str],
     },
     total=False,
 )
@@ -1447,7 +1447,7 @@ _RequiredModifyDBSubnetGroupMessageRequestTypeDef = TypedDict(
     "_RequiredModifyDBSubnetGroupMessageRequestTypeDef",
     {
         "DBSubnetGroupName": str,
-        "SubnetIds": List[str],
+        "SubnetIds": Sequence[str],
     },
 )
 _OptionalModifyDBSubnetGroupMessageRequestTypeDef = TypedDict(
@@ -1485,7 +1485,7 @@ _OptionalModifyEventSubscriptionMessageRequestTypeDef = TypedDict(
     {
         "SnsTopicArn": str,
         "SourceType": str,
-        "EventCategories": List[str],
+        "EventCategories": Sequence[str],
         "Enabled": bool,
     },
     total=False,
@@ -1704,7 +1704,7 @@ RemoveTagsFromResourceMessageRequestTypeDef = TypedDict(
     "RemoveTagsFromResourceMessageRequestTypeDef",
     {
         "ResourceName": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1718,7 +1718,7 @@ _OptionalResetDBClusterParameterGroupMessageRequestTypeDef = TypedDict(
     "_OptionalResetDBClusterParameterGroupMessageRequestTypeDef",
     {
         "ResetAllParameters": bool,
-        "Parameters": List["ParameterTypeDef"],
+        "Parameters": Sequence["ParameterTypeDef"],
     },
     total=False,
 )
@@ -1762,14 +1762,14 @@ _RequiredRestoreDBClusterFromSnapshotMessageRequestTypeDef = TypedDict(
 _OptionalRestoreDBClusterFromSnapshotMessageRequestTypeDef = TypedDict(
     "_OptionalRestoreDBClusterFromSnapshotMessageRequestTypeDef",
     {
-        "AvailabilityZones": List[str],
+        "AvailabilityZones": Sequence[str],
         "EngineVersion": str,
         "Port": int,
         "DBSubnetGroupName": str,
-        "VpcSecurityGroupIds": List[str],
-        "Tags": List["TagTypeDef"],
+        "VpcSecurityGroupIds": Sequence[str],
+        "Tags": Sequence["TagTypeDef"],
         "KmsKeyId": str,
-        "EnableCloudwatchLogsExports": List[str],
+        "EnableCloudwatchLogsExports": Sequence[str],
         "DeletionProtection": bool,
     },
     total=False,
@@ -1805,10 +1805,10 @@ _OptionalRestoreDBClusterToPointInTimeMessageRequestTypeDef = TypedDict(
         "UseLatestRestorableTime": bool,
         "Port": int,
         "DBSubnetGroupName": str,
-        "VpcSecurityGroupIds": List[str],
-        "Tags": List["TagTypeDef"],
+        "VpcSecurityGroupIds": Sequence[str],
+        "Tags": Sequence["TagTypeDef"],
         "KmsKeyId": str,
-        "EnableCloudwatchLogsExports": List[str],
+        "EnableCloudwatchLogsExports": Sequence[str],
         "DeletionProtection": bool,
     },
     total=False,
